@@ -19,7 +19,7 @@ import logging
 
 from pygraph.classes.digraph import digraph
 
-from django_detect_cyclic.utils import PyPlete, SCOPE_GLOBAL
+from django_detect_cyclic.utils import PyPlete, SCOPE_GLOBAL, format_color
 
 from django_detect_cyclic.graph_utils import find_all_cycle, print_graph, treatment_final_graph
 from django_detect_cyclic.utils import get_applications, print_log_info, print_log_error
@@ -32,16 +32,21 @@ def create_graph_apps_dependence(file_name, include_apps=None, exclude_apps=None
                                  exclude_packages=None, verbosity=1, show_modules=False,
                                  remove_isolate_nodes=False, remove_sink_nodes=False,
                                  remove_source_nodes=False, only_cyclic=False, scope=None,
-                                 force_colors=False, dotted_scope_local=False):
+                                 force_colors=False, dotted_scope_local=False,
+                                 layout='dot'):
+    if only_cyclic:
+        remove_isolate_nodes = True
     start_time = datetime.datetime.now()
     use_colors = force_colors or file_name.endswith('.svg')
     gr = create_graph(include_apps, exclude_apps, exclude_packages, verbosity, show_modules, scope, use_colors, dotted_scope_local)
     find_all_cycle(gr, use_colors=use_colors)
     treatment_final_graph(gr, remove_isolate_nodes, remove_sink_nodes, remove_source_nodes,
                               only_cyclic, verbosity=verbosity)
-    print_graph(gr, file_name)
+    if file_name:
+        print_graph(gr, file_name, layout)
     if print_log_info(verbosity):
         log.info("Duration: %s" % str(datetime.datetime.now() - start_time))
+    return gr
 
 
 def create_graph(include_apps=None, exclude_apps=None, exclude_packages=None, verbosity=0,
@@ -143,7 +148,9 @@ def _add_edge(gr, node1, node2, verbosity=1, style="filled"):
         weight = gr.edge_weight((node1, node2)) + 1
         gr.set_edge_weight((node1, node2), weight)
         gr.set_edge_label((node1, node2), "(%s)" % weight)
-    gr.add_edge_attribute((node1, node2), ("style", style))
+    attributes = dict(gr.edge_attributes((node1, node2)))
+    attributes['style'] = style
+    gr.edge_attr[(node1, node2)] = attributes.items()
 
 
 def _has_scope_global(gr, node1, node2):
@@ -197,8 +204,8 @@ def _get_app_colors(app):
     for ch in app:
         color += ord(ch) * int('754321', 16)
     color = int(color % int('ffffff', 16))
-    fillcolor = '#%s' % hex(color)
-    fontcolor = '#%s' % hex(abs(color - int('7fffff', 16)))
+    fillcolor = format_color(hex(color))
+    fontcolor = format_color(hex(abs(color - int('7fffff', 16))))
     return (fillcolor, fontcolor)
 
 
