@@ -18,7 +18,7 @@ from optparse import make_option
 from django.core.management.base import BaseCommand
 from django_detect_cyclic.apps_dependence import create_graph_apps_dependence
 from django_detect_cyclic.exceptions import InvalidOptions
-from django_detect_cyclic.utils import SCOPE_GLOBAL
+from django_detect_cyclic.utils import SCOPE_GLOBAL, DEFAULT_FILENAME, DEFAULT_LAYOUT, DEFAULT_FORMAT, compatible_scope
 
 
 class Command(BaseCommand):
@@ -28,26 +28,28 @@ class Command(BaseCommand):
                     help='Only use these applications to the graph (separated by commas)'),
             make_option('-e', '--exclude-apps', dest='exclude_apps',
                     help='Exclude these apps to the graph (separated by commas)'),
-            make_option('-f', '--file-name', dest='file_name', default='detect.svg',
-                    help='Exclude these apps to the graph (separated by commas)'),
+            make_option('-f', '--file-name', dest='file_name', default='%s.%s' % (DEFAULT_FILENAME, DEFAULT_FORMAT),
+                    help='The name to the generated path (you can set with path)'),
             make_option('-p', '--exclude-packages', dest='exclude_packages',
                     help='Exclude the next packages. For example migrations,templatetags (separated by commas)'),
-            make_option('-r', '--remove-isolate-nodes', dest='remove_isolate_nodes',  action="store_true",
-                    help='Remove the isolate nodes'),
-            make_option('-k', '--remove-sink-nodes', dest='remove_sink_nodes',  action="store_true",
-                    help='Remove the sink nodes'),
-            make_option('-a', '--remove-source-nodes', dest='remove_source_nodes',  action="store_true",
-                    help='Remove the source nodes'),
-            make_option('-o', '--only-cyclic', dest='only_cyclic',  action="store_true",
-                    help='Remove the nodes without cyclic'),
-            make_option('-s', '--show-modules', dest='show_modules',  action="store_true",
-                    help='The nodes now are the modules (by default are the applications)'),
-            make_option('-g', '--scope-global', dest='scope_global',  action="store_true",
-                    help='The imports into the functions are ignored'),
             make_option('-c', '--force-colors', dest='force_colors',  action="store_true",
                     help='You can use this option when the format are not svg'),
+            make_option('-g', '--scope-global', dest='scope_global',  action="store_true",
+                    help='The imports into the functions are ignored'),
             make_option('-d', '--dotted-scope-local', dest='dotted_scope_local',  action="store_true",
                     help='The imports into the functions are printing with dotted line'),
+            make_option('-s', '--show-modules', dest='show_modules',  action="store_true",
+                    help='The nodes now are the modules (by default are the applications)'),
+            make_option('-o', '--only-cyclic', dest='only_cyclic',  action="store_true",
+                    help='Removes the nodes that do not belong to any cycle'),
+            make_option('-r', '--remove-isolate-nodes', dest='remove_isolate_nodes',  action="store_true",
+                    help='Removes the isolate nodes'),
+            make_option('-k', '--remove-sink-nodes', dest='remove_sink_nodes',  action="store_true",
+                    help='Removes the sink nodes'),
+            make_option('-a', '--remove-source-nodes', dest='remove_source_nodes',  action="store_true",
+                    help='Removes the source nodes'),
+            make_option('-l', '--layout', dest='layout', default=DEFAULT_LAYOUT,
+                    help='Removes the source nodes'),
     )
 
     def handle(self, *args, **options):
@@ -63,14 +65,13 @@ class Command(BaseCommand):
         remove_sink_nodes = options['remove_sink_nodes']
         remove_source_nodes = options['remove_source_nodes']
         only_cyclic = options['only_cyclic']
-        if only_cyclic:
-            remove_isolate_nodes = True
         show_modules = options['show_modules']
         file_name = options['file_name']
         force_colors = options['force_colors']
         dotted_scope_local = options['dotted_scope_local']
-        scope = options['scope_global'] and SCOPE_GLOBAL or None
-        if dotted_scope_local and scope == SCOPE_GLOBAL:
+        scope_global = options['scope_global']
+        scope = scope_global and SCOPE_GLOBAL or None
+        if not compatible_scope(dotted_scope_local, scope_global):
             raise InvalidOptions("The dotted-scope-local and scope-global are incompatibles")
         create_graph_apps_dependence(file_name=file_name,
                                      include_apps=include_apps,
